==> nextcloud-29.0.10.tgz: nextcloud/apps/systemtags/l10n/sv.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Systemtagg %1$s tillagt av systemet",
    "Added system tag {systemtag}" : "La till systemtagg {systemtag}",
    "Added system tag %1$s" : "La till systemtagg %1$s",
    "%1$s added system tag %2$s" : "%1$s la till systemtagg %2$s",
    "{actor} added system tag {systemtag}" : "{actor} la till systemtagg {systemtag}",
    "System tag %1$s removed by the system" : "Systemtagg %1$s borttagen av systemet",
    "Removed system tag {systemtag}" : "Tog bort systemtagg {systemtag}",
    "Removed system tag %1$s" : "Tog bort systemtagg %1$s",
    "%1$s removed system tag %2$s" : "%1$s tog bort systemtagg %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} tog bort systemtagg {systemtag}",
    "You created system tag %1$s" : "Du skapade systemtagg %1$s",
    "You created system tag {systemtag}" : "Du skapade systemtagg {systemtag}",
    "%1$s created system tag %2$s" : "%1$s skapade systemtagg %2$s",
    "{actor} created system tag {systemtag}" : "{actor} skapade systemtagg {systemtag}",
    "You deleted system tag %1$s" : "Du tog bort systemtagg %1$s",
    "You deleted system tag {systemtag}" : "Du tog bort systemtagg {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s tog bort systemtagg %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} tog bort systemtagg {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du uppdaterade systemtagg %2$s till %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppdaterade systemtagg %3$s till %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systemtagg %2$s adderades till %1$s av systemet",
    "System tag {systemtag} was added to {file} by the system" : "Systemtagg {systemtag} adderades till {file} av systemet",
    "You added system tag %2$s to %1$s" : "Du la till systemtagg %2$s på %1$s",
    "You added system tag {systemtag} to {file}" : "Du la till systemtagg {systemtag} på {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s la till systemtagg %3$s på %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} la till systemtagg {systemtag} på {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systemtagg %2$s togs bort från %1$s av systemet",
    "System tag {systemtag} was removed from {file} by the system" : "Systemtagg {systemtag} togs bort från {file} av systemet",
    "You removed system tag %2$s from %1$s" : "Du tog bort systemtagg %2$s från %1$s",
    "You removed system tag {systemtag} from {file}" : "Du tog bort systemtagg {systemtag} från {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s tog bort systemtagg %3$s från %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} tog bort systemtagg {systemtag} från {file}",
    "%s (restricted)" : "%s (begränsad)",
    "%s (invisible)" : "%s (osynlig)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systemtaggar</strong> för en fil har blivit ändrade",
    "Files" : "Filer",
    "Tags" : "Taggar",
    "All tagged %s …" : "Alla taggade %s …",
    "tagged %s" : "taggade %s",
    "Collaborative tags" : "Samarbetstaggar",
    "Collaborative tagging functionality which shares tags among people." : "Samarbetande tagg-funktionalitet som delar taggar bland användare.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samarbetande tagg-funktionalitet som delar taggar bland användare. Utmärkt för arbetsgrupper.\n\t(Om du är en leverantör med flera kunder, rekommenderas att deaktivera den här appen eftersom taggar delas.)",
    "Create or edit tags" : "Skapa eller redigera taggar",
    "Search for a tag to edit" : "Sök efter en tagg att redigera",
    "Collaborative tags …" : "Samarbetstaggar ...",
    "No tags to select" : "Inga taggar att välja",
    "Tag name" : "Namn på tagg",
    "Tag level" : "Taggnivå",
    "Create" : "Skapa",
    "Update" : "Uppdatera",
    "Delete" : "Ta bort",
    "Reset" : "Återställ",
    "Loading …" : "Laddar ...",
    "Public" : "Offentlig",
    "Restricted" : "Begränsad",
    "Invisible" : "Osynlig",
    "Created tag" : "Skapade tagg",
    "Failed to create tag" : "Det gick inte att skapa tagg",
    "Updated tag" : "Uppdaterade tagg",
    "Failed to update tag" : "Kunde inte uppdatera tagg",
    "Deleted tag" : "Raderade tagg",
    "Failed to delete tag" : "Det gick inte att ta bort tagg",
    "Manage tags" : "Hantera taggar",
    "Applying tags changes…" : "Tillämpar taggändringar...",
    "Search or create tag" : "Sök eller skapa tagg",
    "Create new tag" : "Skapa ny tagg",
    "Select or create tags to apply to all selected files" : "Välj eller skapa taggar som ska tillämpas på alla valda filer",
    "Cancel" : "Avbryt",
    "Apply changes" : "Tillämpa ändringar",
    "{displayName} (hidden)" : "{displayName} (dold)",
    "{displayName} (restricted)" : "{displayName} (begränsad)",
    "Failed to apply tags changes" : "Kunde inte tillämpa taggändringar",
    "File tags modification canceled" : "Ändring av filtaggar avbröts",
    "Loading collaborative tags …" : "Läser in samarbetstaggar …",
    "Search or create collaborative tags" : "Sök eller skapa samarbetstaggar",
    "No tags to select, type to create a new tag" : "Inga taggar att välja, skriv för att skapa en ny tagg",
    "Failed to load tags" : "Kunde inte läsa in taggar",
    "Failed to load selected tags" : "Det gick inte att läsa in valda taggar",
    "Failed to select tag" : "Det gick inte att välja tagg",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samarbetstaggar är tillgängliga för alla användare. Begränsade taggar är synliga för användarna men kan inte tilldelas av dem. Osynliga taggar är för internt bruk, eftersom användarna inte kan se eller tilldela dem.",
    "Assigned collaborative tags" : "Tilldelade samarbetstaggar",
    "Open in Files" : "Öppna i Filer",
    "List of tags and their associated files and folders." : "Lista över taggar och deras tillhörande filer och mappar.",
    "No tags found" : "Inga taggar hittades",
    "Tags you have created will show up here." : "Taggar du har skapat kommer att visas här.",
    "Failed to load tag" : "Kunde inte läsa in tagg",
    "Failed to load last used tags" : "Det gick inte att läsa in senast använda taggar",
    "Missing \"Content-Location\" header" : "\"Content-Location\" header saknas",
    "A tag with the same name already exists" : "En tagg med samma namn finns redan",
    "Failed to load tags for file" : "Kunde inte läsa in taggar för filen",
    "Failed to set tag for file" : "Kunde inte sätta tagg för filen",
    "Failed to delete tag for file" : "Kunde inte ta bort tagg för filen",
    "Collaborative tagging functionality which shares tags among users." : "Samarbetande tagg-funktionalitet som delar taggar bland användare.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samarbetande tagg-funktionalitet som delar taggar bland användare. Utmärkt för arbetsgrupper.\n\t(Om du är en leverantör med flera kunder, rekommenderas att deaktivera den här appen eftersom taggar delas.)",
    "This file has the tag {tag}" : "Den här filen har taggen {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Den här filen har taggarna {firstTags} och {lastTag}",
    "No files in here" : "Inga filer här inne",
    "No entries found in this folder" : "Ingenting hittades i denna mapp",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Modifierad"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/systemtags/l10n/sv.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Systemtagg %1$s tillagt av systemet",
    "Added system tag {systemtag}" : "La till systemtagg {systemtag}",
    "Added system tag %1$s" : "La till systemtagg %1$s",
    "%1$s added system tag %2$s" : "%1$s la till systemtagg %2$s",
    "{actor} added system tag {systemtag}" : "{actor} la till systemtagg {systemtag}",
    "System tag %1$s removed by the system" : "Systemtagg %1$s borttagen av systemet",
    "Removed system tag {systemtag}" : "Tog bort systemtagg {systemtag}",
    "Removed system tag %1$s" : "Tog bort systemtagg %1$s",
    "%1$s removed system tag %2$s" : "%1$s tog bort systemtagg %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} tog bort systemtagg {systemtag}",
    "You created system tag %1$s" : "Du skapade systemtagg %1$s",
    "You created system tag {systemtag}" : "Du skapade systemtagg {systemtag}",
    "%1$s created system tag %2$s" : "%1$s skapade systemtagg %2$s",
    "{actor} created system tag {systemtag}" : "{actor} skapade systemtagg {systemtag}",
    "You deleted system tag %1$s" : "Du tog bort systemtagg %1$s",
    "You deleted system tag {systemtag}" : "Du tog bort systemtagg {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s tog bort systemtagg %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} tog bort systemtagg {systemtag}",
    "You updated system tag %2$s to %1$s" : "Du uppdaterade systemtagg %2$s till %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Du uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppdaterade systemtagg %3$s till %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uppdaterade systemtagg {oldsystemtag} till {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systemtagg %2$s adderades till %1$s av systemet",
    "System tag {systemtag} was added to {file} by the system" : "Systemtagg {systemtag} adderades till {file} av systemet",
    "You added system tag %2$s to %1$s" : "Du la till systemtagg %2$s på %1$s",
    "You added system tag {systemtag} to {file}" : "Du la till systemtagg {systemtag} på {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s la till systemtagg %3$s på %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} la till systemtagg {systemtag} på {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systemtagg %2$s togs bort från %1$s av systemet",
    "System tag {systemtag} was removed from {file} by the system" : "Systemtagg {systemtag} togs bort från {file} av systemet",
    "You removed system tag %2$s from %1$s" : "Du tog bort systemtagg %2$s från %1$s",
    "You removed system tag {systemtag} from {file}" : "Du tog bort systemtagg {systemtag} från {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s tog bort systemtagg %3$s från %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} tog bort systemtagg {systemtag} från {file}",
    "%s (restricted)" : "%s (begränsad)",
    "%s (invisible)" : "%s (osynlig)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systemtaggar</strong> för en fil har blivit ändrade",
    "Files" : "Filer",
    "Tags" : "Taggar",
    "All tagged %s …" : "Alla taggade %s …",
    "tagged %s" : "taggade %s",
    "Collaborative tags" : "Samarbetstaggar",
    "Collaborative tagging functionality which shares tags among people." : "Samarbetande tagg-funktionalitet som delar taggar bland användare.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samarbetande tagg-funktionalitet som delar taggar bland användare. Utmärkt för arbetsgrupper.\n\t(Om du är en leverantör med flera kunder, rekommenderas att deaktivera den här appen eftersom taggar delas.)",
    "Create or edit tags" : "Skapa eller redigera taggar",
    "Search for a tag to edit" : "Sök efter en tagg att redigera",
    "Collaborative tags …" : "Samarbetstaggar ...",
    "No tags to select" : "Inga taggar att välja",
    "Tag name" : "Namn på tagg",
    "Tag level" : "Taggnivå",
    "Create" : "Skapa",
    "Update" : "Uppdatera",
    "Delete" : "Ta bort",
    "Reset" : "Återställ",
    "Loading …" : "Laddar ...",
    "Public" : "Offentlig",
    "Restricted" : "Begränsad",
    "Invisible" : "Osynlig",
    "Created tag" : "Skapade tagg",
    "Failed to create tag" : "Det gick inte att skapa tagg",
    "Updated tag" : "Uppdaterade tagg",
    "Failed to update tag" : "Kunde inte uppdatera tagg",
    "Deleted tag" : "Raderade tagg",
    "Failed to delete tag" : "Det gick inte att ta bort tagg",
    "Manage tags" : "Hantera taggar",
    "Applying tags changes…" : "Tillämpar taggändringar...",
    "Search or create tag" : "Sök eller skapa tagg",
    "Change tag color" : "Ändra färg på tagg",
    "Create new tag" : "Skapa ny tagg",
    "Select or create tags to apply to all selected files" : "Välj eller skapa taggar som ska tillämpas på alla valda filer",
    "Cancel" : "Avbryt",
    "Apply changes" : "Tillämpa ändringar",
    "{displayName} (hidden)" : "{displayName} (dold)",
    "{displayName} (restricted)" : "{displayName} (begränsad)",
    "Failed to apply tags changes" : "Kunde inte tillämpa taggändringar",
    "File tags modification canceled" : "Ändring av filtaggar avbröts",
    "Loading collaborative tags …" : "Läser in samarbetstaggar …",
    "Search or create collaborative tags" : "Sök eller skapa samarbetstaggar",
    "No tags to select, type to create a new tag" : "Inga taggar att välja, skriv för att skapa en ny tagg",
    "Failed to load tags" : "Kunde inte läsa in taggar",
    "Failed to load selected tags" : "Det gick inte att läsa in valda taggar",
    "Failed to select tag" : "Det gick inte att välja tagg",
    "System admin disabled tag creation. You can only use existing ones." : "Systemadministratören har inaktiverat skapandet av taggar. Du kan endast använda befintliga.",
    "System tag creation" : "Skapa systemtaggar",
    "If enabled, regular accounts will be restricted from creating new tags but will still be able to assign and remove them from their files." : "Om det är aktiverat kommer vanliga konton att vara begränsade från att skapa nya taggar men kommer fortfarande att kunna tilldela och ta bort dem från sina filer.",
    "Restrict tag creation to admins only" : "Begränsa skapande av taggar till endast administratörer",
    "Unable to update setting" : "Kunde inte uppdatera inställningen",
    "System tag creation is now restricted to administrators" : "Skapandet av systemtaggar är nu begränsat till administratörer",
    "System tag creation is now allowed for everybody" : "Skapandet av systemtaggar är nu tillåtet för alla",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samarbetstaggar är tillgängliga för alla användare. Begränsade taggar är synliga för användarna men kan inte tilldelas av dem. Osynliga taggar är för internt bruk, eftersom användarna inte kan se eller tilldela dem.",
    "Assigned collaborative tags" : "Tilldelade samarbetstaggar",
    "Open in Files" : "Öppna i Filer",
    "List of tags and their associated files and folders." : "Lista över taggar och deras tillhörande filer och mappar.",
    "No tags found" : "Inga taggar hittades",
    "Tags you have created will show up here." : "Taggar du har skapat kommer att visas här.",
    "Failed to load tag" : "Kunde inte läsa in tagg",
    "Failed to load last used tags" : "Det gick inte att läsa in senast använda taggar",
    "Missing \"Content-Location\" header" : "\"Content-Location\" header saknas",
    "A tag with the same name already exists" : "En tagg med samma namn finns redan",
    "Failed to load tags for file" : "Kunde inte läsa in taggar för filen",
    "Failed to set tag for file" : "Kunde inte sätta tagg för filen",
    "Failed to delete tag for file" : "Kunde inte ta bort tagg för filen",
    "This file has the tag {tag}" : "Den här filen har taggen {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Den här filen har taggarna {firstTags} och {lastTag}",
    "System tag creation is now ${isRestricted ? " : "Skapande av systemtaggar är nu ${isRestricted ? "
},
"nplurals=2; plural=(n != 1);");
